@@ -9,8 +9,8 @@ from pydap.exceptions import ConstraintExpressionError
 
 
 __author__  = 'Roberto De Almeida <rob@pydap.org>'
-__version__ = (3,0,3)       # pydap version
-__dap__     = (2,0)       # protocol version
+__version__ = (3,1)       # pydap version
+__dap__     = (2,15)       # protocol version
 
 
 # Global variables -- I know we should try to avoid them, but we need
@@ -147,7 +147,7 @@ def hyperslab(slices):
         >>> print hyperslab( (slice(0, 10, 2), slice(1, 20, 2)) )
         [0:2:9][1:2:19]
         >>> print hyperslab( (slice(0, 10, 2), slice(None), slice(1, 20, 2)) )
-        [0:2:9][0:1:2147483646][1:2:19]
+        [0:2:9][0:1:%d][1:2:19]
         >>> print hyperslab( (slice(0, 10, 2), slice(1, 20, 2), slice(None)) )
         [0:2:9][1:2:19]
 
@@ -156,7 +156,8 @@ def hyperslab(slices):
         >>> print hyperslab(slice(0, 10, 2))
         [0:2:9]
 
-    """
+    """ % sys.maxint
+
     if not isinstance(slices, tuple): slices = [slices]
     else: slices = list(slices)
 
@@ -274,7 +275,7 @@ def parse_qs(query):
 
     """
     projection = []
-    selection = [urllib.unquote(token) for token in query.split('&') if token]
+    selection = [token for token in urllib.unquote(query).split('&') if token]
     if selection and not re.search('<=|>=|!=|=~|>|<|=', selection[0]): 
         projection = [p for p in selection.pop(0).split(',') if p]
 
@@ -282,7 +283,7 @@ def parse_qs(query):
     for var in projection:
         tokens = var.split('.')
         tokens = [re.match('(.*?)(\[.*\])?$', token).groups() for token in tokens]
-        tokens = [(token, get_slice(slice_ or '')) for (token, slice_) in tokens]
+        tokens = [(urllib.quote(token), get_slice(slice_ or '')) for (token, slice_) in tokens]
         fields.append(tokens)
 
     return fields, selection
